@@ -37,9 +37,6 @@
 /* From seahorse-prefs-cache.c */
 void seahorse_prefs_cache (SeahorseWidget *widget);
 
-/* From sehorse-prefs-keyrings.c */
-void seahorse_prefs_keyrings (SeahorseWidget *widget);
-
 /* Key Server Prefs --------------------------------------------------------- */
 
 #ifdef WITH_KEYSERVER
@@ -481,9 +478,8 @@ SeahorseWidget *
 seahorse_prefs_new (GtkWindow *parent)
 {
     SeahorseWidget *swidget;
-#ifndef WITH_KEYSERVER
     GtkWidget *widget = NULL;
-#endif
+
     
     swidget = seahorse_widget_new ("prefs", parent);
     
@@ -503,8 +499,6 @@ seahorse_prefs_new (GtkWindow *parent)
     seahorse_prefs_remove_tab (swidget, widget);
 #endif    
 
-    seahorse_prefs_keyrings (swidget);
-
     seahorse_widget_show (swidget);
     return swidget;
 }
