@@ -29,79 +29,86 @@
 
 #include "common/seahorse-registry.h"
 
-G_DEFINE_TYPE (SeahorseSource, seahorse_source, G_TYPE_OBJECT);
-
-/* GObject handlers */
-static void seahorse_source_dispose    (GObject *gobject);
-static void seahorse_source_finalize   (GObject *gobject);
-
-static GObjectClass *parent_class = NULL;
+/* ---------------------------------------------------------------------------------
+ * INTERFACE
+ */
 
 static void
-seahorse_source_class_init (SeahorseSourceClass *klass)
+seahorse_source_base_init (gpointer gobject_class)
 {
-    GObjectClass *gobject_class;
-   
-    parent_class = g_type_class_peek_parent (klass);
-    gobject_class = G_OBJECT_CLASS (klass);
-    
-    gobject_class->dispose = seahorse_source_dispose;
-    gobject_class->finalize = seahorse_source_finalize;
+	static gboolean initialized = FALSE;
+	if (!initialized) {
+		
+		/* Add properties and signals to the interface */
+		g_object_interface_install_property (gobject_class,
+		        g_param_spec_uint ("source-tag", "Source Tag", "Tag of objects that come from this source.", 
+		                           0, G_MAXUINT, SEAHORSE_TAG_INVALID, G_PARAM_READABLE));
+
+		g_object_interface_install_property (gobject_class, 
+		        g_param_spec_enum ("source-location", "Source Location", "Objects in this source are at this location. See SeahorseLocation", 
+		                           SEAHORSE_TYPE_LOCATION, SEAHORSE_LOCATION_LOCAL, G_PARAM_READABLE));
+		
+		initialized = TRUE;
+	}
 }
 
-/* Initialize the object */
-static void
-seahorse_source_init (SeahorseSource *sksrc)
+GType
+seahorse_source_get_type (void)
 {
-
+	static GType type = 0;
+	if (!type) {
+		static const GTypeInfo info = {
+			sizeof (SeahorseSourceIface),
+			seahorse_source_base_init,               /* base init */
+			NULL,             /* base finalize */
+			NULL,             /* class_init */
+			NULL,             /* class finalize */
+			NULL,             /* class data */
+			0,
+			0,                /* n_preallocs */
+			NULL,             /* instance init */
+		};
+		type = g_type_register_static (G_TYPE_INTERFACE, "SeahorseSourceIface", &info, 0);
+		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
+	}
+	
+	return type;
 }
 
-/* dispose of all our internal references */
-static void
-seahorse_source_dispose (GObject *gobject)
-{
-    G_OBJECT_CLASS (parent_class)->dispose (gobject);
-}
-
-/* free private vars */
-static void
-seahorse_source_finalize (GObject *gobject)
-{
-    G_OBJECT_CLASS (parent_class)->finalize (gobject);
-}
+/* ---------------------------------------------------------------------------------
+ * PUBLIC
+ */
 
 /**
  * seahorse_source_load
  * @sksrc: A #SeahorseSource object
- * @id: The object to refresh or 0 for all.
  * 
  * Refreshes the #SeahorseSource's internal object listing. 
  * 
  * Returns the asynchronous refresh operation. 
  **/   
 SeahorseOperation*
-seahorse_source_load (SeahorseSource *sksrc, GQuark id)
+seahorse_source_load (SeahorseSource *sksrc)
 {
-    SeahorseSourceClass *klass;
+    SeahorseSourceIface *klass;
     
     g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), NULL);
-    klass = SEAHORSE_SOURCE_GET_CLASS (sksrc);
+    klass = SEAHORSE_SOURCE_GET_INTERFACE (sksrc);
     g_return_val_if_fail (klass->load != NULL, NULL);
     
-    return (*klass->load) (sksrc, id);
+    return (*klass->load) (sksrc);
 }
 
 /**
  * seahorse_source_load_sync
  * @sksrc: A #SeahorseSource object
- * @id: The object to refresh or 0 for all.
  * 
  * Refreshes the #SeahorseSource's internal object listing, and waits for it to complete.
  **/   
 void
-seahorse_source_load_sync (SeahorseSource *sksrc, GQuark id)
+seahorse_source_load_sync (SeahorseSource *sksrc)
 {
-    SeahorseOperation *op = seahorse_source_load (sksrc, id);
+    SeahorseOperation *op = seahorse_source_load (sksrc);
     g_return_if_fail (op != NULL);
     seahorse_operation_wait (op);
     g_object_unref (op);
@@ -110,14 +117,13 @@ seahorse_source_load_sync (SeahorseSource *sksrc, GQuark id)
 /**
  * seahorse_source_load_sync
  * @sksrc: A #SeahorseSource object
- * @id: The object to refresh or 0 for all.
  * 
  * Refreshes the #SeahorseSource's internal object listing. Completes in the background.
  **/   
 void
-seahorse_source_load_async (SeahorseSource *sksrc, GQuark id)
+seahorse_source_load_async (SeahorseSource *sksrc)
 {
-    SeahorseOperation *op = seahorse_source_load (sksrc, id);
+    SeahorseOperation *op = seahorse_source_load (sksrc);
     g_return_if_fail (op != NULL);
     g_object_unref (op);
 }
@@ -134,10 +140,10 @@ seahorse_source_load_async (SeahorseSource *sksrc, GQuark id)
 SeahorseOperation*
 seahorse_source_search (SeahorseSource *sksrc, const gchar *match)
 {
-    SeahorseSourceClass *klass;
+    SeahorseSourceIface *klass;
     
     g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), NULL);
-    klass = SEAHORSE_SOURCE_GET_CLASS (sksrc);
+    klass = SEAHORSE_SOURCE_GET_INTERFACE (sksrc);
     g_return_val_if_fail (klass->search != NULL, NULL);
     
     return (*klass->search) (sksrc, match);
@@ -146,12 +152,12 @@ seahorse_source_search (SeahorseSource *sksrc, const gchar *match)
 SeahorseOperation* 
 seahorse_source_import (SeahorseSource *sksrc, GInputStream *input)
 {
-	SeahorseSourceClass *klass;
+	SeahorseSourceIface *klass;
     
 	g_return_val_if_fail (G_IS_INPUT_STREAM (input), NULL);
     
 	g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), NULL);
-	klass = SEAHORSE_SOURCE_GET_CLASS (sksrc);   
+	klass = SEAHORSE_SOURCE_GET_INTERFACE (sksrc);   
 	g_return_val_if_fail (klass->import != NULL, NULL);
     
 	return (*klass->import) (sksrc, input);  
@@ -241,7 +247,6 @@ seahorse_source_delete_objects (GList *objects)
 {
 	SeahorseOperation *op = NULL;
 	SeahorseMultiOperation *mop = NULL;
-	SeahorseSource *sksrc;
 	SeahorseObject *sobj;
 	GList *l;
 
@@ -250,18 +255,13 @@ seahorse_source_delete_objects (GList *objects)
 		sobj = SEAHORSE_OBJECT (l->data);
 		g_return_val_if_fail (SEAHORSE_IS_OBJECT (sobj), NULL);;
 		
-		/* Export from this object source */        
-		sksrc = seahorse_object_get_source (sobj);
-		g_return_val_if_fail (sksrc != NULL, NULL);
-
 		if (op != NULL) {
 			if (mop == NULL)
 				mop = seahorse_multi_operation_new ();
 			seahorse_multi_operation_take (mop, op);
 		}
 
-		/* We pass our own data object, to which data is appended */
-		op = seahorse_source_remove (sksrc, l->data);
+		op = seahorse_object_delete (sobj);
 		g_return_val_if_fail (op != NULL, NULL);
 	}
     
@@ -277,7 +277,7 @@ seahorse_source_delete_objects (GList *objects)
 SeahorseOperation* 
 seahorse_source_export (SeahorseSource *sksrc, GList *objects, GOutputStream *output)
 {
-	SeahorseSourceClass *klass;
+	SeahorseSourceIface *klass;
 	SeahorseOperation *op;
 	GSList *ids = NULL;
 	GList *l;
@@ -285,7 +285,7 @@ seahorse_source_export (SeahorseSource *sksrc, GList *objects, GOutputStream *ou
 	g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), NULL);
 	g_return_val_if_fail (G_IS_OUTPUT_STREAM (output), NULL);
 	
-	klass = SEAHORSE_SOURCE_GET_CLASS (sksrc);   
+	klass = SEAHORSE_SOURCE_GET_INTERFACE (sksrc);   
 	if (klass->export)
 		return (*klass->export) (sksrc, objects, output);
 
@@ -304,7 +304,7 @@ seahorse_source_export (SeahorseSource *sksrc, GList *objects, GOutputStream *ou
 SeahorseOperation* 
 seahorse_source_export_raw (SeahorseSource *sksrc, GSList *ids, GOutputStream *output)
 {
-	SeahorseSourceClass *klass;
+	SeahorseSourceIface *klass;
 	SeahorseOperation *op;
 	SeahorseObject *sobj;
 	GList *objects = NULL;
@@ -313,7 +313,7 @@ seahorse_source_export_raw (SeahorseSource *sksrc, GSList *ids, GOutputStream *o
 	g_return_val_if_fail (SEAHORSE_IS_SOURCE (sksrc), NULL);
 	g_return_val_if_fail (output == NULL || G_IS_OUTPUT_STREAM (output), NULL);
 
-	klass = SEAHORSE_SOURCE_GET_CLASS (sksrc);   
+	klass = SEAHORSE_SOURCE_GET_INTERFACE (sksrc);   
     
 	/* Either export or export_raw must be implemented */
 	if (klass->export_raw)
@@ -334,28 +334,12 @@ seahorse_source_export_raw (SeahorseSource *sksrc, GSList *ids, GOutputStream *o
 	g_list_free (objects);
 	return op;
 }
-
-SeahorseOperation*           
-seahorse_source_remove (SeahorseSource *src, SeahorseObject *sobj)
-{
-	SeahorseSourceClass *klass;
-
-	g_return_val_if_fail (SEAHORSE_IS_SOURCE (src), NULL);
-	g_return_val_if_fail (SEAHORSE_IS_OBJECT (sobj), NULL);
-	g_return_val_if_fail (seahorse_object_get_source (sobj) == src, NULL);
-    
-	g_return_val_if_fail (SEAHORSE_IS_SOURCE (src), FALSE);
-	klass = SEAHORSE_SOURCE_GET_CLASS (src);
-	g_return_val_if_fail (klass->remove != NULL, FALSE);
-    
-	return (*klass->remove) (src, sobj);    
-}
-                                               
+                                     
 GQuark              
-seahorse_source_get_ktype (SeahorseSource *sksrc)
+seahorse_source_get_tag (SeahorseSource *sksrc)
 {
     GQuark ktype;
-    g_object_get (sksrc, "key-type", &ktype, NULL);
+    g_object_get (sksrc, "source-tag", &ktype, NULL);
     return ktype;
 }
 
@@ -363,28 +347,6 @@ SeahorseLocation
 seahorse_source_get_location (SeahorseSource *sksrc)
 {
     SeahorseLocation loc;
-    g_object_get (sksrc, "location", &loc, NULL);
+    g_object_get (sksrc, "source-location", &loc, NULL);
     return loc;
 }
-
-/* -----------------------------------------------------------------------------
- * CANONICAL IDS 
- */
-
-GQuark
-seahorse_source_canonize_id (GQuark ktype, const gchar *id)
-{
-	SeahorseSourceClass *klass;
-	GType type;
-
-	g_return_val_if_fail (id != NULL, 0);
-    
-	type = seahorse_registry_find_type (NULL, "key-source", g_quark_to_string (ktype), "local", NULL);
-	g_return_val_if_fail (type, 0);
-	
-	klass = SEAHORSE_SOURCE_CLASS (g_type_class_peek (type));
-	g_return_val_if_fail (klass, 0);
-	
-	g_return_val_if_fail (klass->canonize_id, 0);
-	return (klass->canonize_id) (id);
-}
