@@ -534,7 +534,7 @@ add_key (SeahorseHKPSource *ssrc, SeahorsePgpKey *key)
 	SeahorseObject *prev;
 	GQuark keyid;
        
-	keyid = seahorse_pgp_key_calc_cannonical_id (seahorse_pgp_key_get_keyid (key));
+	keyid = seahorse_pgp_key_canonize_id (seahorse_pgp_key_get_keyid (key));
 	prev = seahorse_context_get_object (SCTX_APP (), SEAHORSE_SOURCE (ssrc), keyid);
 	if (prev != NULL) {
 		g_return_if_fail (SEAHORSE_IS_PGP_KEY (prev));
@@ -1001,7 +1001,7 @@ seahorse_hkp_source_class_init (SeahorseHKPSourceClass *klass)
 	seahorse_registry_register_type (NULL, SEAHORSE_TYPE_HKP_SOURCE, "source", "remote", SEAHORSE_PGP_STR, NULL);
 	seahorse_servers_register_type ("hkp", _("HTTP Key Server"), seahorse_hkp_is_valid_uri);
 	
-	seahorse_registry_register_function (NULL, seahorse_pgp_key_calc_cannonical_id, "canonize", SEAHORSE_PGP_STR, NULL);
+	seahorse_registry_register_function (NULL, seahorse_pgp_key_canonize_id, "canonize", SEAHORSE_PGP_STR, NULL);
 }
 
 static void 
